@@ -1,3 +1,4 @@
+from ast import literal_eval
 from sentinels import NOTHING
 from .exceptions import InvalidPath
 from .exceptions import CannotDeduceType
@@ -17,6 +18,7 @@ def assign_path_expression(conf, expr, deduce_type=False):
         value = _coerce_leaf_value(path, value, leaf)
     assign_path(conf, path, value)
 
+_COMPOUND_TYPES = [list, tuple]
 _VALUES_FOR_TRUE = ['yes', 'y', 'true', 't']
 _VALUES_FOR_FALSE = ['no', 'n', 'false', 'f']
 
@@ -27,8 +29,10 @@ def _coerce_leaf_value(path, value, leaf):
     if leaf_type is bool:
         value = value.lower()
         if value not in _VALUES_FOR_TRUE and value not in _VALUES_FOR_FALSE:
-            raise ValueError('Invalid value for boolean: {!r}'.format(value))
+            raise ValueError('Invalid value for boolean: {0!r}'.format(value))
         return value in _VALUES_FOR_TRUE
+    if leaf_type in _COMPOUND_TYPES:
+        return literal_eval(value)
     return leaf_type(value)
 
 def get_path(conf, path):
@@ -37,7 +41,7 @@ def get_path(conf, path):
     for p in path_components:
         key = returned.get(p, NOTHING)
         if key is NOTHING:
-            raise InvalidPath("Invalid path: {0!r}".format(path))
+            raise InvalidPath("Invalid config path: {0!r}".format(path))
         returned = returned[p]
     return returned
 
